@@ -157,7 +157,7 @@ Out-of-the-box implementation of this Construct (without any overridden properti
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -173,15 +173,15 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_ec2
-import aws_cdk.aws_lambda
-import aws_cdk.aws_lambda_event_sources
-import aws_cdk.aws_sqs
-import constructs
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_ceddda9d
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_ceddda9d
+import aws_cdk.aws_lambda_event_sources as _aws_cdk_aws_lambda_event_sources_ceddda9d
+import aws_cdk.aws_sqs as _aws_cdk_aws_sqs_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class LambdaToSqsToLambda(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-lambda-sqs-lambda.LambdaToSqsToLambda",
 ):
@@ -191,23 +191,23 @@ class LambdaToSqsToLambda(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        consumer_lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        consumer_lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        dead_letter_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         deploy_vpc: typing.Optional[builtins.bool] = None,
-        existing_consumer_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        existing_producer_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        existing_consumer_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+        existing_producer_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+        existing_queue_obj: typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue] = None,
+        existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        producer_lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        producer_lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
         queue_environment_variable_name: typing.Optional[builtins.str] = None,
-        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-        sqs_event_source_props: typing.Optional[typing.Union[aws_cdk.aws_lambda_event_sources.SqsEventSourceProps, typing.Dict[str, typing.Any]]] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        sqs_event_source_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_event_sources_ceddda9d.SqsEventSourceProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -231,27 +231,7 @@ class LambdaToSqsToLambda(
         :summary: Constructs a new instance of the LambdaToSqsToLambda class.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                consumer_lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
-                deploy_vpc: typing.Optional[builtins.bool] = None,
-                existing_consumer_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-                existing_producer_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                max_receive_count: typing.Optional[jsii.Number] = None,
-                producer_lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-                queue_environment_variable_name: typing.Optional[builtins.str] = None,
-                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                sqs_event_source_props: typing.Optional[typing.Union[aws_cdk.aws_lambda_event_sources.SqsEventSourceProps, typing.Dict[str, typing.Any]]] = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4dcac242d39b60acc1536a4e2dca319a038d2c2c5381764f0b31c2314148ec91)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = LambdaToSqsToLambdaProps(
@@ -275,28 +255,30 @@ class LambdaToSqsToLambda(
 
     @builtins.property
     @jsii.member(jsii_name="consumerLambdaFunction")
-    def consumer_lambda_function(self) -> aws_cdk.aws_lambda.Function:
-        return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "consumerLambdaFunction"))
+    def consumer_lambda_function(self) -> _aws_cdk_aws_lambda_ceddda9d.Function:
+        return typing.cast(_aws_cdk_aws_lambda_ceddda9d.Function, jsii.get(self, "consumerLambdaFunction"))
 
     @builtins.property
     @jsii.member(jsii_name="producerLambdaFunction")
-    def producer_lambda_function(self) -> aws_cdk.aws_lambda.Function:
-        return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "producerLambdaFunction"))
+    def producer_lambda_function(self) -> _aws_cdk_aws_lambda_ceddda9d.Function:
+        return typing.cast(_aws_cdk_aws_lambda_ceddda9d.Function, jsii.get(self, "producerLambdaFunction"))
 
     @builtins.property
     @jsii.member(jsii_name="sqsQueue")
-    def sqs_queue(self) -> aws_cdk.aws_sqs.Queue:
-        return typing.cast(aws_cdk.aws_sqs.Queue, jsii.get(self, "sqsQueue"))
+    def sqs_queue(self) -> _aws_cdk_aws_sqs_ceddda9d.Queue:
+        return typing.cast(_aws_cdk_aws_sqs_ceddda9d.Queue, jsii.get(self, "sqsQueue"))
 
     @builtins.property
     @jsii.member(jsii_name="deadLetterQueue")
-    def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue]:
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue], jsii.get(self, "deadLetterQueue"))
+    def dead_letter_queue(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.DeadLetterQueue]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_ceddda9d.DeadLetterQueue], jsii.get(self, "deadLetterQueue"))
 
     @builtins.property
     @jsii.member(jsii_name="vpc")
-    def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], jsii.get(self, "vpc"))
+    def vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc], jsii.get(self, "vpc"))
 
 
 @jsii.data_type(
@@ -323,20 +305,20 @@ class LambdaToSqsToLambdaProps:
     def __init__(
         self,
         *,
-        consumer_lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        consumer_lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        dead_letter_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         deploy_vpc: typing.Optional[builtins.bool] = None,
-        existing_consumer_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        existing_producer_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        existing_consumer_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+        existing_producer_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+        existing_queue_obj: typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue] = None,
+        existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        producer_lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        producer_lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
         queue_environment_variable_name: typing.Optional[builtins.str] = None,
-        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-        sqs_event_source_props: typing.Optional[typing.Union[aws_cdk.aws_lambda_event_sources.SqsEventSourceProps, typing.Dict[str, typing.Any]]] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        sqs_event_source_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_event_sources_ceddda9d.SqsEventSourceProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param consumer_lambda_function_props: Optional user-provided properties to override the default properties for the consumer Lambda function. Default: - Default properties are used.
@@ -357,37 +339,19 @@ class LambdaToSqsToLambdaProps:
         :summary: The properties for the LambdaToSqsToLambda class.
         '''
         if isinstance(consumer_lambda_function_props, dict):
-            consumer_lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**consumer_lambda_function_props)
+            consumer_lambda_function_props = _aws_cdk_aws_lambda_ceddda9d.FunctionProps(**consumer_lambda_function_props)
         if isinstance(dead_letter_queue_props, dict):
-            dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(**dead_letter_queue_props)
+            dead_letter_queue_props = _aws_cdk_aws_sqs_ceddda9d.QueueProps(**dead_letter_queue_props)
         if isinstance(producer_lambda_function_props, dict):
-            producer_lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**producer_lambda_function_props)
+            producer_lambda_function_props = _aws_cdk_aws_lambda_ceddda9d.FunctionProps(**producer_lambda_function_props)
         if isinstance(queue_props, dict):
-            queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
+            queue_props = _aws_cdk_aws_sqs_ceddda9d.QueueProps(**queue_props)
         if isinstance(sqs_event_source_props, dict):
-            sqs_event_source_props = aws_cdk.aws_lambda_event_sources.SqsEventSourceProps(**sqs_event_source_props)
+            sqs_event_source_props = _aws_cdk_aws_lambda_event_sources_ceddda9d.SqsEventSourceProps(**sqs_event_source_props)
         if isinstance(vpc_props, dict):
-            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+            vpc_props = _aws_cdk_aws_ec2_ceddda9d.VpcProps(**vpc_props)
         if __debug__:
-            def stub(
-                *,
-                consumer_lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
-                deploy_vpc: typing.Optional[builtins.bool] = None,
-                existing_consumer_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-                existing_producer_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                max_receive_count: typing.Optional[jsii.Number] = None,
-                producer_lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-                queue_environment_variable_name: typing.Optional[builtins.str] = None,
-                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                sqs_event_source_props: typing.Optional[typing.Union[aws_cdk.aws_lambda_event_sources.SqsEventSourceProps, typing.Dict[str, typing.Any]]] = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__35d74c84b8d1f96157035ad48360aa4c6ddbfdc76eaf72f6fd4cf24fec06f8bf)
             check_type(argname="argument consumer_lambda_function_props", value=consumer_lambda_function_props, expected_type=type_hints["consumer_lambda_function_props"])
             check_type(argname="argument dead_letter_queue_props", value=dead_letter_queue_props, expected_type=type_hints["dead_letter_queue_props"])
             check_type(argname="argument deploy_dead_letter_queue", value=deploy_dead_letter_queue, expected_type=type_hints["deploy_dead_letter_queue"])
@@ -402,7 +366,7 @@ class LambdaToSqsToLambdaProps:
             check_type(argname="argument queue_props", value=queue_props, expected_type=type_hints["queue_props"])
             check_type(argname="argument sqs_event_source_props", value=sqs_event_source_props, expected_type=type_hints["sqs_event_source_props"])
             check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if consumer_lambda_function_props is not None:
             self._values["consumer_lambda_function_props"] = consumer_lambda_function_props
         if dead_letter_queue_props is not None:
@@ -435,16 +399,18 @@ class LambdaToSqsToLambdaProps:
     @builtins.property
     def consumer_lambda_function_props(
         self,
-    ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
+    ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps]:
         '''Optional user-provided properties to override the default properties for the consumer Lambda function.
 
         :default: - Default properties are used.
         '''
         result = self._values.get("consumer_lambda_function_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps], result)
 
     @builtins.property
-    def dead_letter_queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
+    def dead_letter_queue_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.QueueProps]:
         '''Optional user-provided props to override the default props for the dead letter queue.
 
         Only used if the
@@ -453,7 +419,7 @@ class LambdaToSqsToLambdaProps:
         :default: - Default props are used.
         '''
         result = self._values.get("dead_letter_queue_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.QueueProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_ceddda9d.QueueProps], result)
 
     @builtins.property
     def deploy_dead_letter_queue(self) -> typing.Optional[builtins.bool]:
@@ -478,7 +444,7 @@ class LambdaToSqsToLambdaProps:
     @builtins.property
     def existing_consumer_lambda_obj(
         self,
-    ) -> typing.Optional[aws_cdk.aws_lambda.Function]:
+    ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function]:
         '''An optional, existing Lambda function to be used instead of the default function for receiving/consuming messages from the queue.
 
         Providing both this and ``consumerLambdaFunctionProps`` will cause an error.
@@ -486,12 +452,12 @@ class LambdaToSqsToLambdaProps:
         :default: - None.
         '''
         result = self._values.get("existing_consumer_lambda_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function], result)
 
     @builtins.property
     def existing_producer_lambda_obj(
         self,
-    ) -> typing.Optional[aws_cdk.aws_lambda.Function]:
+    ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function]:
         '''An optional, existing Lambda function to be used instead of the default function for sending messages to the queue.
 
         Providing both this and ``producerLambdaFunctionProps`` property will cause an error.
@@ -499,10 +465,10 @@ class LambdaToSqsToLambdaProps:
         :default: - None.
         '''
         result = self._values.get("existing_producer_lambda_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function], result)
 
     @builtins.property
-    def existing_queue_obj(self) -> typing.Optional[aws_cdk.aws_sqs.Queue]:
+    def existing_queue_obj(self) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue]:
         '''An optional, existing SQS queue to be used instead of the default queue.
 
         Providing both this and ``queueProps``
@@ -511,13 +477,13 @@ class LambdaToSqsToLambdaProps:
         :default: - None.
         '''
         result = self._values.get("existing_queue_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.Queue], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue], result)
 
     @builtins.property
-    def existing_vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
+    def existing_vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc]:
         '''An existing VPC for the construct to use (construct will NOT create a new VPC in this case).'''
         result = self._values.get("existing_vpc")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc], result)
 
     @builtins.property
     def max_receive_count(self) -> typing.Optional[jsii.Number]:
@@ -536,13 +502,13 @@ class LambdaToSqsToLambdaProps:
     @builtins.property
     def producer_lambda_function_props(
         self,
-    ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
+    ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps]:
         '''Optional user-provided properties to override the default properties for the producer Lambda function.
 
         :default: - Default properties are used.
         '''
         result = self._values.get("producer_lambda_function_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps], result)
 
     @builtins.property
     def queue_environment_variable_name(self) -> typing.Optional[builtins.str]:
@@ -554,30 +520,30 @@ class LambdaToSqsToLambdaProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
+    def queue_props(self) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.QueueProps]:
         '''Optional user-provided properties to override the default properties for the SQS queue.
 
         :default: - Default props are used.
         '''
         result = self._values.get("queue_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.QueueProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_ceddda9d.QueueProps], result)
 
     @builtins.property
     def sqs_event_source_props(
         self,
-    ) -> typing.Optional[aws_cdk.aws_lambda_event_sources.SqsEventSourceProps]:
+    ) -> typing.Optional[_aws_cdk_aws_lambda_event_sources_ceddda9d.SqsEventSourceProps]:
         '''Optional user provided properties for the queue event source.
 
         :default: - Default props are used
         '''
         result = self._values.get("sqs_event_source_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda_event_sources.SqsEventSourceProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_event_sources_ceddda9d.SqsEventSourceProps], result)
 
     @builtins.property
-    def vpc_props(self) -> typing.Optional[aws_cdk.aws_ec2.VpcProps]:
+    def vpc_props(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.VpcProps]:
         '''Properties to override default properties if deployVpc is true.'''
         result = self._values.get("vpc_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.VpcProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.VpcProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -597,3 +563,45 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__4dcac242d39b60acc1536a4e2dca319a038d2c2c5381764f0b31c2314148ec91(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    consumer_lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    dead_letter_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+    deploy_vpc: typing.Optional[builtins.bool] = None,
+    existing_consumer_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+    existing_producer_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+    existing_queue_obj: typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue] = None,
+    existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    max_receive_count: typing.Optional[jsii.Number] = None,
+    producer_lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    queue_environment_variable_name: typing.Optional[builtins.str] = None,
+    queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    sqs_event_source_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_event_sources_ceddda9d.SqsEventSourceProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__35d74c84b8d1f96157035ad48360aa4c6ddbfdc76eaf72f6fd4cf24fec06f8bf(
+    *,
+    consumer_lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    dead_letter_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+    deploy_vpc: typing.Optional[builtins.bool] = None,
+    existing_consumer_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+    existing_producer_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+    existing_queue_obj: typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue] = None,
+    existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    max_receive_count: typing.Optional[jsii.Number] = None,
+    producer_lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    queue_environment_variable_name: typing.Optional[builtins.str] = None,
+    queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    sqs_event_source_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_event_sources_ceddda9d.SqsEventSourceProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
